@@ -1,4 +1,6 @@
-const esModules = ['p-limit', 'yocto-queue', 'vue-material-design-icons'].join('|')
+const esModules = [
+	'p-limit',
+].join('|')
 
 module.exports = {
 	preset: 'ts-jest',
@@ -15,6 +17,7 @@ module.exports = {
 		'^.+\\.ts$': 'ts-jest',
 		'^.+\\.js$': 'babel-jest',
 		'^.+\\.vue$': '@vue/vue2-jest',
+		'^.+\\.(css|styl|less|sass|scss|jpg|jpeg|png|svg|gif|eot|otf|webp|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga|avif)$': 'jest-transform-stub',
 	},
-	transformIgnorePatterns: [`/node_modules/(?!${esModules})`],
+	transformIgnorePatterns: [`/node_modules/(?!${esModules})/.+\\.js$`],
 }
