@@ -29,7 +29,9 @@ OC.L10N.register(
     "Update avatars from social media" : "SNSでアバターをアップデート",
     "(refreshed once per week)" : "(週に1回更新)",
     "Address books" : "アドレス帳",
+    "Export" : "エクスポート",
     "Send email" : "メールを送信",
+    "Send email as BCC" : "BCCでメール送信",
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
     "Contact group name" : "連絡先グループ名",
@@ -42,7 +44,9 @@ OC.L10N.register(
     "This group already exists" : "このグループはすでに存在しています",
     "This circle already exists" : "このサークルはすでに存在します",
     "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
+    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
     "Download" : "ダウンロード",
+    "Show" : "表示",
     "Rename" : "名前を変更",
     "Delete" : "削除",
     "Copied" : "コピーしました",
@@ -53,8 +57,11 @@ OC.L10N.register(
     "Delete {addressbook}?" : "{addressbook} を削除しますか？",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
+    "_%n contact_::_%n contacts_" : ["%n 連絡先"],
+    "_%n group_::_%n groups_" : ["%n グループ"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
     "Share with users or groups" : "ユーザーまたはグループと共有する",
+    "Share with users" : "ユーザーに共有",
     "No users or groups" : "ユーザーまたはグループはありません",
     "can edit" : "編集を許可",
     "Unable to delete the share" : "共有を削除できません",
@@ -92,13 +99,18 @@ OC.L10N.register(
     "Enter a description for the circle" : "サークルについて説明を入力してください",
     "An error happened during description sync" : "説明の同期中にエラーが発生しました",
     "An error happened during name sync" : "名前の同期中にエラーが発生しました",
+    "Add more info" : "さらに情報を追加",
+    "More fields" : "その他のフィールド",
+    "Crop contact photo" : "写真を切り抜き",
     "Cancel" : "キャンセル",
     "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from Files" : "ファイルから選択",
     "Get from " : "次から入手:",
     "Download picture" : "画像をダウンロード",
     "Delete picture" : "画像を削除",
+    "Please select a valid format" : "有効なフォーマットを選択してください。",
     "Invalid image" : "無効な画像",
+    "Error cropping picture" : "画像のトリミング中にエラーが発生しました",
     "Pick an avatar" : "アバターを選択",
     "Error while processing the picture." : "画像の加工中にエラーが発生しました",
     "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
@@ -110,21 +122,26 @@ OC.L10N.register(
     "Title" : "タイトル",
     "Company" : "会社",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
+    "Edit" : "編集",
     "Clone contact" : "連絡先の複製",
     "Generate QR Code" : "QRコードを生成",
     "Contact vCard as QR code" : "QRコードでの連絡先vCard",
     "Pick an address book" : "アドレス帳を選ぶ",
     "Select address book" : "アドレス帳を選ぶ",
+    "Go to talk conversation" : "Talkのチャットへ移動",
+    "View profile" : "プロフィールを表示",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Address book" : "アドレス帳",
     "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
     "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
-    "New contact" : "新しい連絡先",
+    "{title} at {organization}" : "{organization}の{title}",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
+    "The contact does not exist on the server anymore." : "連絡先はサーバー上に存在しません。",
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
+    "Unable to update contact" : "連絡先を更新できません",
     "Search contacts …" : "連絡先を検索...",
     "Add to {group}" : "{group}に追加",
     "Remove {type}" : "{type} を削除",
@@ -165,7 +182,10 @@ OC.L10N.register(
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
+    "none" : "なし",
     "Select option" : "オプションを選択",
+    "Add property of this type" : "このタイプのプロパティーを追加",
+    "New contact" : "新しい連絡先",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
@@ -190,6 +210,7 @@ OC.L10N.register(
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
     "Organization chart" : "組織図",
+    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "サークルは自分で作成できるグループで、データを共有する先として利用できます。サークルは、Nextcloudインスタンスのアカウントやグループだけでなく、アドレス帳に登録されている連絡先やメールアドレスを入力して外部の人も追加してグループを構成できます。",
     "Circle" : "サークル",
     "User" : "ユーザー",
     "Group" : "グループ",
@@ -270,6 +291,7 @@ OC.L10N.register(
     "Time zone" : "時間帯",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
+    "An error has occurred in circle(s). Check the console for more details." : "サークルでエラーが発生しました。コンソールで詳細を確認してください。",
     "Unable to create circle {circleName}" : "サークル {circleName} を作成できません",
     "Unable to delete circle {circleId}" : "サークル{circleId}を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。"
