@@ -130,13 +130,17 @@ OC.L10N.register(
     "Select address book" : "選擇通訊錄",
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
+    "Media shares with you" : "與您分享的媒體",
+    "Talk conversations with you" : "與您的 Talk 對話",
+    "Calendar events with you" : "有您的日曆事件",
+    "Deck cards with you" : "有您的 Deck 卡片",
+    "No shared items with this contact" : "沒有與該聯絡人分享的項目",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
     "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
     "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
     "{title} at {organization}" : "{organization} 的 {title}",
-    "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
     "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
@@ -186,6 +190,7 @@ OC.L10N.register(
     "none" : "無",
     "Select option" : "選取選項",
     "Add property of this type" : "新增此類型的屬性",
+    "New contact" : "新聯絡人",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
