@@ -31,7 +31,6 @@ use OCP\IRequest;
 use OCP\IURLGenerator;
 
 class ContactsController extends Controller {
-
 	/** @var IL10N */
 	private $l10n;
 
@@ -61,4 +60,19 @@ class ContactsController extends Controller {
 		);
 		return new RedirectResponse($url);
 	}
+
+
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 *
+	 * Open and find direct circle
+	 * @param string $uuid
+	 */
+	public function directCircle(string $singleId): RedirectResponse {
+		$url = $this->urlGenerator->getAbsoluteURL(
+			$this->urlGenerator->linkToRoute('contacts.page.index') . 'circle/' . $singleId
+		);
+		return new RedirectResponse($url);
+	}
 }
